<?php
namespace Folha\Logic\ESocial\Eventos\Data;
use Folha\Repositories\GpeEsocialRegistro;

/**
 * Classe provedora do datasource utilizado para a geracao do evento S-1310 - Serviços Tomados mediante cessão de mão de
 * obra.
 *
 * @package Folha\Logic\ESocial\Eventos\Data
 * @author felipesantos
 **/
class S1310
{

    /**
     * Retorna os dados que serao utilizado para a geracao do(s) arquivo(s) do evento S-1310, Serviços Tomados mediante
     * cessão de mão de obra.
     *
     * @param $dsordem                 Define as possíveis formas de filtro utilizadas pela tela de envio de eventos  
     *                                 do e-Social. Pode ser ALFABETICA, MATRICULA, DATA_ADMISSAO e ESTRUTURA. Para este
     *                                 evento, em especial, somente o filtro por ESTRUTURA poderá será relevante.
     * @param $limiteInferior          Limite inferior do filtro aplicado. O significado dos dados trazidos neste campo
     *                                 deverao variar, conforme o parametro dsordem.
     * @param $limiteSuperior          Limite superior do filtro aplicado. O significado dos dados trazidos neste campo
     *                                 deverao variar, conforme o parametro dsordem.
     * @param $inicioPeriodo           Inicio do intervalo que deverá ter os eventos gerados. Somente será utilizado se
     *                                 o parametro "$utilizaIntervaloDeDatas" for igual a "true". 
     * @param $fimPeriodo              Final do intervalo que deverá ter os eventos gerados. Somente será utilizado se
     *                                 o parametro "$utilizaIntervaloDeDatas" for igual a "true".
     * @param $utilizaIntervaloDeDatas Verifica se o dataset deve ser filtrado pelos campos de intervalo da tela de  
     *                                 envio de eventos e-Social, ou se devem enviados os arquivos alterados depois do 
     *                                 ultimo envio.
     * @param $idRetificacao           Identificador de Retificação dos arquivos ou não.
     * @param $nrRecibo                Número do Recibo do primeiro envio em caso de Retificação.
     * @param $idApuracao              Identificador da apuração Mensal ou Anual.
     * @param $nrorg                   Nrorg.
     * @param $versaoHRM               Versao do sistema HRM utilizado para a geracao dos relatorios.
     *
     * @return array
     * @author felipesantos
     **/
    public static function getDataSource($dsordem, $limiteInferior, $limiteSuperior, $inicioPeriodo, $fimPeriodo, 
                                         $utilizaIntervaloDeDatas, $nrorg, $versaoHRM, $idRetificacao, $nrRecibo, $idApuracao)
    {
        $S1310 = GpeEsocialRegistro::dataSetEsocial_S1310(
            $dsordem, $limiteInferior, $limiteSuperior, $inicioPeriodo, $fimPeriodo, 
            $utilizaIntervaloDeDatas, $nrorg, $versaoHRM, $idRetificacao, $nrRecibo, $idApuracao
        );

        // Loop para gerar os estabelecimentos tomadores referentes ao empregador acima
        foreach ($S1310 as &$row) {
            $estabs = GpeEsocialRegistro::s13xx_EstabPrestTomad('E', $row['NRESTRUTURAM'], $inicioPeriodo, $fimPeriodo, $nrorg);

            // Loop para gerar os prestadores referentes ao estabelecimento acima
            $contEstab = 1;
            $estabelecimento = null;
            foreach($estabs as &$estab) {
                $prests = GpeEsocialRegistro::s13xx_PrestadTomador('E', $estab['CDFILIRECE'], $inicioPeriodo, $fimPeriodo, null);

                // Loop para gerar as notas referentes ao prestador acima
                $contPrest = 1;
                $prestador = null;
                foreach($prests as &$prest) {
                    $notas = GpeEsocialRegistro::s13xx_NfServPrestTomad('E', $estab['CDFILIRECE'], $prest['CDFORNECED'], $inicioPeriodo, $fimPeriodo);

                    // Loop para gerar os itens referentes à nota acima
                    $contNF = 1;
                    $nfTerceiros = null;
                    foreach ($notas as &$notafiscal) {
                        $itens = GpeEsocialRegistro::s13xx_ItensNotaFiscal($notafiscal['CDFILIAL'], $notafiscal['NRLANCTONF']);

                        $contItem = 1;
                        $itemNF = null;
                        foreach ($itens as &$item) {
                            $itemNF[$contItem] =
                                array("_EVTFPSERVTOMADOS_INFOSERVTOMADOS_IDEESTABELECIMENTO_IDEPRESTADORSERVICOS_NFSTERCEIROS_ITENSNFS" => '1',
                                    "_EVTFPSERVTOMADOS_INFOSERVTOMADOS_IDEESTABELECIMENTO_IDEPRESTADORSERVICOS_NFSTERCEIROS_ITENSNFS_NRITEM" => $item['NRITEM'],
                                    "_EVTFPSERVTOMADOS_INFOSERVTOMADOS_IDEESTABELECIMENTO_IDEPRESTADORSERVICOS_NFSTERCEIROS_ITENSNFS_TPSERVICO" => $item['TPSERVICO'],
                                    "_EVTFPSERVTOMADOS_INFOSERVTOMADOS_IDEESTABELECIMENTO_IDEPRESTADORSERVICOS_NFSTERCEIROS_ITENSNFS_VLRBRUTO" => $item['VLRBRUTO'],
                                    "_EVTFPSERVTOMADOS_INFOSERVTOMADOS_IDEESTABELECIMENTO_IDEPRESTADORSERVICOS_NFSTERCEIROS_ITENSNFS_VLRBASERETENCAO" => $item['VLRBASERETENCAO']);
                            $contItem++;
                        }

                        $nfTerceiros[$contNF] =
                            array("_EVTFPSERVTOMADOS_INFOSERVTOMADOS_IDEESTABELECIMENTO_IDEPRESTADORSERVICOS_NFSTERCEIROS" => '1',
                                "_EVTFPSERVTOMADOS_INFOSERVTOMADOS_IDEESTABELECIMENTO_IDEPRESTADORSERVICOS_NFSTERCEIROS_SERIE" => $notafiscal['SERIE'],
                                "_EVTFPSERVTOMADOS_INFOSERVTOMADOS_IDEESTABELECIMENTO_IDEPRESTADORSERVICOS_NFSTERCEIROS_NUMDOCTO" => $notafiscal['NUMDOCTO'],
                                "_EVTFPSERVTOMADOS_INFOSERVTOMADOS_IDEESTABELECIMENTO_IDEPRESTADORSERVICOS_NFSTERCEIROS_DTEMISSAONF" => $notafiscal['DTEMISSAONF'],
                                "_EVTFPSERVTOMADOS_INFOSERVTOMADOS_IDEESTABELECIMENTO_IDEPRESTADORSERVICOS_NFSTERCEIROS_INDOBRA" => $notafiscal['INDOBRA'],
                                "_EVTFPSERVTOMADOS_INFOSERVTOMADOS_IDEESTABELECIMENTO_IDEPRESTADORSERVICOS_NFSTERCEIROS_NRCNO" => $notafiscal['NRCNO'],
                                "_EVTFPSERVTOMADOS_INFOSERVTOMADOS_IDEESTABELECIMENTO_IDEPRESTADORSERVICOS_NFSTERCEIROS_VLRBRUTO" => $notafiscal['VLRBRUTO'],
                                "_EVTFPSERVTOMADOS_INFOSERVTOMADOS_IDEESTABELECIMENTO_IDEPRESTADORSERVICOS_NFSTERCEIROS_VLRBASERETENCAO" => $notafiscal['VLRBASERETENCAO'],
                                "_EVTFPSERVTOMADOS_INFOSERVTOMADOS_IDEESTABELECIMENTO_IDEPRESTADORSERVICOS_NFSTERCEIROS_VLRRETENCAOAPURADA" => $notafiscal['VLRRETENCAOAPURADA'],
                                "_EVTFPSERVTOMADOS_INFOSERVTOMADOS_IDEESTABELECIMENTO_IDEPRESTADORSERVICOS_NFSTERCEIROS_VLRRETENCAOSUBEMPREITADA" => $notafiscal['VLRRETENCAOSUBEMPREITADA'],
                                "_EVTFPSERVTOMADOS_INFOSERVTOMADOS_IDEESTABELECIMENTO_IDEPRESTADORSERVICOS_NFSTERCEIROS_VLRRETENCAO" => $notafiscal['VLRRETENCAO'],
                                "_EVTFPSERVTOMADOS_INFOSERVTOMADOS_IDEESTABELECIMENTO_IDEPRESTADORSERVICOS_NFSTERCEIROS_VLRADICIONAL" => $notafiscal['VLRADICIONAL'],
                                "_EVTFPSERVTOMADOS_INFOSERVTOMADOS_IDEESTABELECIMENTO_IDEPRESTADORSERVICOS_NFSTERCEIROS_ITENSNFS" => $itemNF);
                        $contNF++;
                    }

                    $prestador[$contPrest] =
                        array("_EVTFPSERVTOMADOS_INFOSERVTOMADOS_IDEESTABELECIMENTO_IDEPRESTADORSERVICOS" => '1',
                            "_EVTFPSERVTOMADOS_INFOSERVTOMADOS_IDEESTABELECIMENTO_IDEPRESTADORSERVICOS_CNPJPRESTADOR" => $estab['CNPJPRESTADOR'],
                            "_EVTFPSERVTOMADOS_INFOSERVTOMADOS_IDEESTABELECIMENTO_IDEPRESTADORSERVICOS_VLRBRUTO" => $estab['VLRBRUTO'],
                            "_EVTFPSERVTOMADOS_INFOSERVTOMADOS_IDEESTABELECIMENTO_IDEPRESTADORSERVICOS_VLRBASERETENCAO" => $estab['VLRBASERETENCAO'],
                            "_EVTFPSERVTOMADOS_INFOSERVTOMADOS_IDEESTABELECIMENTO_IDEPRESTADORSERVICOS_VLRRETENCAO" => $estab['VLRRETENCAO'],
                            "_EVTFPSERVTOMADOS_INFOSERVTOMADOS_IDEESTABELECIMENTO_IDEPRESTADORSERVICOS_VLRADICIONAL" => $estab['VLRADICIONAL'],
                            "_EVTFPSERVTOMADOS_INFOSERVTOMADOS_IDEESTABELECIMENTO_IDEPRESTADORSERVICOS_VLRNAORETIDO" => $estab['VLRNAORETIDO'],
                            "_EVTFPSERVTOMADOS_INFOSERVTOMADOS_IDEESTABELECIMENTO_IDEPRESTADORSERVICOS_NFSTERCEIROS" => $nfTerceiros);
                    $contPrest++;
                }

                $estabelecimento[$contEstab] =
                    array("_EVTFPSERVTOMADOS_INFOSERVTOMADOS_IDEESTABELECIMENTO" => '1',
                        "_EVTFPSERVTOMADOS_INFOSERVTOMADOS_IDEESTABELECIMENTO_TPINSCRICAO" => $estab['ESTABTPINSCRICAO'],
                        "_EVTFPSERVTOMADOS_INFOSERVTOMADOS_IDEESTABELECIMENTO_NRINSCRICAO" => $estab['ESTABNRINSCRICAO'],
                        "_EVTFPSERVTOMADOS_INFOSERVTOMADOS_IDEESTABELECIMENTO_IDEPRESTADORSERVICOS" => $prestador);
                $contEstab++;
            }

            $row['_EVTFPSERVTOMADOS_INFOSERVTOMADOS_IDEESTABELECIMENTO'][1] = $estabelecimento;
        }

        return $S1310;
    }

}