/* Tabela IMPRLOJA: TABELA DE IMPRESSORAS POR LOJA */
/* Descrio: A trigger insere registros na tabela LOGOPERAVND a partir de alteraes na tabela IMPRLOJA*/
/* Objetivo: Gerar um log que vai registrar as alteraes na IMPRLOJA,
             utilizando a tabela de Logs de Operaes do VND*/

IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'LOG_VND_IMPRLOJA' AND
                 TYPE   = 'TR' 	               AND
	              U.UID  = O.UID           AND
	              U.NAME = USER)
DROP TRIGGER LOG_VND_IMPRLOJA
GO

CREATE TRIGGER LOG_VND_IMPRLOJA
ON IMPRLOJA
FOR INSERT, UPDATE, DELETE
AS
  DECLARE @V_DSREMOTEADDR VARCHAR(15);
  DECLARE @V_DSREMOTEHOST VARCHAR(15);
  DECLARE @V_DSSERVERRDM  VARCHAR(20);
  DECLARE @V_DSSERVMETHOD VARCHAR(30);
  DECLARE @V_DSREMOTEOPER VARCHAR(12);
  DECLARE @V_DESC         VARCHAR(500);
  DECLARE @V_ITPESQ       VARCHAR(40);
  DECLARE @V_NMOPERADOR   VARCHAR(40);
  DECLARE @V_IDTIPOOPER   VARCHAR(1);

/*VARIVEIS DO CURSOR C_CURSOR*/

  DECLARE @V_ID_COMANDO    VARCHAR(1);

  DECLARE @V_NEW_CDFILIAL        VARCHAR(4);                 
  DECLARE @V_NEW_CDLOJA          VARCHAR(10);                 
  DECLARE @V_NEW_NRSEQIMPRLOJA   VARCHAR(5);                 
  DECLARE @V_NEW_CDIMPRESSORA    VARCHAR(3);                 
  DECLARE @V_NEW_NMIMPRLOJA      VARCHAR(50);                                                  
  DECLARE @V_NEW_CDPORTAIMPR     VARCHAR(5);                                                                             
  DECLARE @V_NEW_DTULTATU        DATE;                                                                             

  DECLARE @V_OLD_CDFILIAL        VARCHAR(4);                 
  DECLARE @V_OLD_CDLOJA          VARCHAR(10);                 
  DECLARE @V_OLD_NRSEQIMPRLOJA   VARCHAR(5);                 
  DECLARE @V_OLD_CDIMPRESSORA    VARCHAR(3);                 
  DECLARE @V_OLD_NMIMPRLOJA      VARCHAR(50);                                                  
  DECLARE @V_OLD_CDPORTAIMPR     VARCHAR(5);                                                                             
  DECLARE @V_OLD_DTULTATU        DATE;   


BEGIN
/* IDTIPOOPER - '1' - Incluso, '2' - Alterao, '3' - Excluso*/


   SET @V_DESC   = '';
   SET @V_ITPESQ     = '';
   SET @V_NMOPERADOR = '';
   SET @V_IDTIPOOPER = '';

   EXEC NMUSUARIO @P_NMUSUARIO = @V_NMOPERADOR OUTPUT;
   SET @V_NMOPERADOR = ISNULL(@V_NMOPERADOR, ' ');

   EXEC WEBTUNNING  @P_DSREMOTEADDR = @V_DSREMOTEADDR OUTPUT,
                    @P_DSREMOTEHOST = @V_DSREMOTEHOST OUTPUT,
                    @P_DSSERVERRDM  = @V_DSSERVERRDM OUTPUT,
                    @P_DSSERVMETHOD = @V_DSSERVMETHOD OUTPUT,
                    @P_DSREMOTEOPER = @V_DSREMOTEOPER OUTPUT;


   DECLARE C_CURSOR CURSOR FOR
     SELECT
     'D'   ID_COMANDO,
           NULL,NULL,NULL,
           NULL,NULL,NULL, NULL,
           DELETED.CDFILIAL,
           DELETED.CDLOJA,
           DELETED.NRSEQIMPRLOJA,
           DELETED.CDIMPRESSORA,
           DELETED.NMIMPRLOJA,
           DELETED.CDPORTAIMPR,
           DELETED.DTULTATU

     FROM
           DELETED
     WHERE     
           DELETED.CDFILIAL + DELETED.CDLOJA + DELETED.NRSEQIMPRLOJA NOT IN (SELECT CDFILIAL + CDLOJA + NRSEQIMPRLOJA FROM INSERTED)
     UNION ALL

     SELECT
     'U'   ID_COMANDO,
           INSERTED.CDFILIAL,
           INSERTED.CDLOJA,
           INSERTED.NRSEQIMPRLOJA,
           INSERTED.CDIMPRESSORA,
           INSERTED.NMIMPRLOJA,
           INSERTED.CDPORTAIMPR,
           INSERTED.DTULTATU,

           DELETED.CDFILIAL,
           DELETED.CDLOJA,
           DELETED.NRSEQIMPRLOJA,
           DELETED.CDIMPRESSORA,
           DELETED.NMIMPRLOJA,
           DELETED.CDPORTAIMPR,
           DELETED.DTULTATU

     FROM
           INSERTED,
           DELETED
     WHERE     
           INSERTED.CDFILIAL  = DELETED.CDFILIAL AND
           INSERTED.CDLOJA  = DELETED.CDLOJA AND
           INSERTED.NRSEQIMPRLOJA  = DELETED.NRSEQIMPRLOJA

     UNION ALL

     SELECT
     'I'   IDCOMANDO,
           INSERTED.CDFILIAL,
           INSERTED.CDLOJA,
           INSERTED.NRSEQIMPRLOJA,
           INSERTED.CDIMPRESSORA,
           INSERTED.NMIMPRLOJA,
           INSERTED.CDPORTAIMPR,
           INSERTED.DTULTATU,
           NULL,NULL,NULL,
           NULL,NULL,NULL, NULL

     FROM
           INSERTED
     WHERE     
           INSERTED.CDFILIAL + INSERTED.CDLOJA + INSERTED.NRSEQIMPRLOJA NOT IN (SELECT CDFILIAL + CDLOJA + NRSEQIMPRLOJA FROM DELETED)


     OPEN C_CURSOR;
     FETCH NEXT FROM C_CURSOR INTO @V_ID_COMANDO,
				   @V_NEW_CDFILIAL,@V_NEW_CDLOJA,@V_NEW_NRSEQIMPRLOJA,@V_NEW_CDIMPRESSORA,
				   @V_NEW_NMIMPRLOJA,@V_NEW_CDPORTAIMPR,@V_NEW_DTULTATU,

				   @V_OLD_CDFILIAL,@V_OLD_CDLOJA,@V_OLD_NRSEQIMPRLOJA,@V_OLD_CDIMPRESSORA,
				   @V_OLD_NMIMPRLOJA,@V_OLD_CDPORTAIMPR,@V_OLD_DTULTATU


    WHILE (@@FETCH_STATUS = 0) BEGIN
    
       IF @V_ID_COMANDO= 'U' /*UPDATE*/ BEGIN
		IF ISNULL(@V_NEW_CDFILIAL,'NULL') <> ISNULL(@V_OLD_CDFILIAL,'NULL') BEGIN
			SET @V_DESC  = 'Filial '               + ISNULL(@V_NEW_CDFILIAL,''    );
		END;
		IF ISNULL(@V_NEW_CDLOJA,'NULL') <> ISNULL(@V_OLD_CDLOJA,'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  Loja  '                + ISNULL(@V_NEW_CDLOJA,''  );
		END;
		IF ISNULL(@V_NEW_NRSEQIMPRLOJA,'NULL') <> ISNULL(@V_OLD_NRSEQIMPRLOJA,'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  Nr Seq Impressora Loja '              + ISNULL(@V_NEW_NRSEQIMPRLOJA,'' );
		END;
		IF ISNULL(@V_NEW_CDIMPRESSORA,'NULL') <> ISNULL(@V_OLD_CDIMPRESSORA,'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  Cd Impressora '              + ISNULL(@V_NEW_CDIMPRESSORA,'' );
		END;
		IF ISNULL(@V_NEW_NMIMPRLOJA,'NULL') <> ISNULL(@V_OLD_NMIMPRLOJA,'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  Nm Impressora '              + ISNULL(@V_NEW_NMIMPRLOJA,'' );
		END;
		IF ISNULL(@V_NEW_CDPORTAIMPR,'NULL') <> ISNULL(@V_OLD_CDPORTAIMPR,'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  Cd Porta Impressora '              + ISNULL(@V_NEW_CDPORTAIMPR,'' );
		END;
		IF ISNULL(CONVERT(VARCHAR,@V_NEW_DTULTATU),'NULL') <> ISNULL(CONVERT(VARCHAR,@V_OLD_DTULTATU),'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  Data Ult Atualizao '  + ISNULL(CONVERT(VARCHAR,@V_NEW_DTULTATU),'');
		END;

          SET @V_IDTIPOOPER = '2';
       END;

       IF @V_ID_COMANDO= 'I' /*INSERO*/ BEGIN
          SET @V_DESC  = 'Filial '               + ISNULL(@V_NEW_CDFILIAL,''    )    +  ' '  + 
                  'Loja  '                + ISNULL(@V_NEW_CDLOJA,''  )        +  ' '  + 
                  'Nr Seq Impressora Loja  '                + ISNULL(@V_NEW_NRSEQIMPRLOJA,''  )        +  ' '  + 
                  'Cd Impressora  '                + ISNULL(@V_NEW_CDIMPRESSORA,''  )        +  ' '  + 
                  'Nm Impressora  '                + ISNULL(@V_NEW_NMIMPRLOJA,''  )        +  ' '  + 
                  'Cd Porta Impressora  '                + ISNULL(@V_NEW_CDPORTAIMPR,''  )        +  ' '  + 
                  'Data Ult Atualizao '  + ISNULL(CONVERT(VARCHAR,@V_NEW_DTULTATU),''); 
          SET @V_IDTIPOOPER = '1';
       END;

       IF @V_ID_COMANDO= 'D' /*DELEO*/  BEGIN
          SET @V_DESC  = 'Filial '               + ISNULL(@V_OLD_CDFILIAL,''    )    +  ' '  + 
                  'Loja  '                + ISNULL(@V_OLD_CDLOJA,''  )        +  ' '  + 
                  'Nr Seq Impressora Loja  '                + ISNULL(@V_OLD_NRSEQIMPRLOJA,''  )        +  ' '  + 
                  'Cd Impressora  '                + ISNULL(@V_OLD_CDIMPRESSORA,''  )        +  ' '  + 
                  'Nm Impressora  '                + ISNULL(@V_OLD_NMIMPRLOJA,''  )        +  ' '  + 
                  'Cd Porta Impressora  '                + ISNULL(@V_OLD_CDPORTAIMPR,''  )        +  ' '  + 
                  'Data Ult Atualizao '  + ISNULL(CONVERT(VARCHAR,@V_OLD_DTULTATU),''); 
          SET @V_IDTIPOOPER = '3';
       END;

       IF  (@V_IDTIPOOPER <> '') BEGIN
          IF @V_DESC IS NOT NULL BEGIN
             SET @V_ITPESQ =  ISNULL(@V_NEW_CDFILIAL + @V_NEW_CDLOJA + @V_NEW_NRSEQIMPRLOJA , @V_OLD_CDFILIAL + @V_OLD_CDLOJA + @V_OLD_NRSEQIMPRLOJA);
             SET @V_DESC = SUBSTRING(@V_DESC, 1, 300);
             INSERT INTO LOGOPERAVND
                     (NMTABELAVND, DTOPERACAOVND, NMRESPOPERVND, IDTIPOOPERVND, DSOPERACAOVND,
                     CDPESQITEMVND, DSRDMUSUOPERVND, DSENDUSUOPERVND, DSNMUSUOPERVND, DSMETUSUOPERVND,
                     CDORESPOPERVND, CDFILLOGOPERVND)
             VALUES ('IMPRLOJA',GETDATE(), ISNULL(@V_NMOPERADOR,' '), @V_IDTIPOOPER, @V_DESC, @V_ITPESQ,
                     @V_DSSERVERRDM, @V_DSREMOTEADDR, @V_DSREMOTEHOST, @V_DSSERVMETHOD, @V_DSREMOTEOPER,
                     ISNULL(@V_NEW_CDFILIAL,@V_OLD_CDFILIAL));
          END;
       END;

       FETCH NEXT FROM C_CURSOR INTO @V_ID_COMANDO,
				   @V_NEW_CDFILIAL,@V_NEW_CDLOJA,@V_NEW_NRSEQIMPRLOJA,@V_NEW_CDIMPRESSORA,
				   @V_NEW_NMIMPRLOJA,@V_NEW_CDPORTAIMPR,@V_NEW_DTULTATU,

				   @V_OLD_CDFILIAL,@V_OLD_CDLOJA,@V_OLD_NRSEQIMPRLOJA,@V_OLD_CDIMPRESSORA,
				   @V_OLD_NMIMPRLOJA,@V_OLD_CDPORTAIMPR,@V_OLD_DTULTATU

    SET @V_DESC   = '';
    END;
    CLOSE      C_CURSOR;
    DEALLOCATE C_CURSOR;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'LOG_VND_IMPRLOJA','5.20.001';
GO









                                                                          
