function OldIntervalController($scope, templateManager, ZhUtil, ScreenService, ZhLogger, validateEngine) {
	
	ZhLogger.warning("The built-in interval.html field is deprecated. Please consider changing to zh-interval-component: http://code.zeedhi.com/stanleypinto/zeedhi-interval-component");

	var self = this;

	var START_FIELD_SUFFIX = "_start";
	var END_FIELD_SUFFIX = "_end";
	var SELECT_SUFFIX = "_period_select";
	var SELECT_INTERVAL_SUFFIX = "_period_name";
	var INCLUSIVE_SUFFIX = "inclusive";

	this.__defineGetter__('field', function() {
		return $scope.field;
	});

	var dateFormat = self.field.dateFormat || "L";

	/** PREDETERMINED PERIODS:
	 *
	 *	The predetermined supported periods are:
	 * - 'today', 'yesterday', 'tomorrow';
	 * - 'this-week', 'last-week', 'next-week';
	 * - 'this-month', 'last-month', 'next-month';
	 * - 'this-quarter', 'last-quarter', 'next-quarter';
	 * - 'this-year', 'last-year', 'next-year';
	 *
	 */

	var exceptionWords = {
		'today': "this-day",
		'yesterday': "last-day",
		'tomorrow': "next-day"
	};

	function getRowObject(word) {
		var decoded = decodeWordExpression(word);
		var buildIntervalMethod = (decoded.suffix === INCLUSIVE_SUFFIX) ? buildIntervalInclusive : buildInterval;
		return buildIntervalMethod(decoded.prefix, decoded.amount, decoded.unit);
	}

	function buildInterval(prefix, amount, unit) {
		var start = moment().startOf(unit),
			end = moment();
		switch (prefix) {
			case 'last':
				end.subtract(1, unit);
				start.subtract(amount, unit);
				break;
			case 'next':
				start.add(1, unit);
				end.add(amount, unit);
				break;
		}
		end.endOf(unit);
		return factoryInterval(start, end);
	}

	function buildIntervalInclusive(prefix, amount, unit) {
		var start = moment().startOf(unit),
			end = moment();
		switch (prefix) {
			case 'last':
				start.subtract(amount - 1, unit);
				break;
			case 'next':
				end.add(amount - 1, unit);
				break;
		}
		end.endOf(unit);
		return factoryInterval(start, end);
	}

	function factoryInterval(start, end) {
		return {
			"start": start.format(dateFormat),
			"end": end.format(dateFormat),
			"customized": false
		};
	}

	function decodeWordExpression(word) {
		// Transform exception words due to function needs
		if (word in exceptionWords) {
			word = exceptionWords[word];
		}

		var prefix, amount, unit, suffix;
		var splitedString = word.split("-");

		if (splitedString.length === 2) {
			prefix = splitedString[0];
			unit = splitedString[1];
		} else if (splitedString.length > 2) {
			prefix = splitedString[0];
			amount = splitedString[1];
			unit = splitedString[2];
			suffix = splitedString[3];
		} else {
			throw "Not Expected String Format";
		}

		return {
			prefix: prefix,
			amount: amount || 1,
			unit: unit,
			suffix: suffix
		};
	}

	function buildIntervals() {
		var intervals = [];

		// Iterates in field periods to build each determined row
		if (Util.isArray(self.field.intervals)) {
			self.field.intervals.forEach(function(interval) {
				try {
					/** NOTE:
					 * - The customized flag is used to tell that such peroid was created by the developer.
					 * - The personalized flag is used to tell that such period will be selected by the user because it's not in the period list.
					 */

					var row;

					// Evaluates possible custom intervals
					if (interval.period[0] === "@") {
						row = ZhUtil.evaluate(interval.period);
						row.customized = true;
					} else {

						var word = interval.period;

						// Gets predeterminded interval row object using the function language
						row = getRowObject(word);

					}

					intervals.push({
						"_period_label": interval.label,
						"_period": row,
						"_period_name": interval.period
					});
				} catch (e) {}
			});
		}

		return intervals;
	}

	// Functions used to generate the child fields
	this.buildDateField = function(name) {
		var minDate = self.field.minDate;
		var maxDate = self.field.maxDate;
		var iFieldValue = self.field.value();

		name = "_" + name;
		if (name === START_FIELD_SUFFIX) {
			maxDate = iFieldValue && iFieldValue.end ? iFieldValue.end : minDate;
		} else if (name === END_FIELD_SUFFIX) {
			minDate = iFieldValue && iFieldValue.start ? iFieldValue.start : minDate;
		}

		var field = {
			"class": "6",
			"name": self.field.name + name,
			"label": ScreenService.i18n((name === START_FIELD_SUFFIX ? "From" : "To")),
			"template": "field/old-calendar.html",
			"dateField": self.field.dateField,
			"titleField": self.field.titleField,
			"dateFormat": self.field.dateFormat,
			"displayFormat": self.field.displayFormat,
			"readOnly": self.field.isReadOnly(),
			"maxDate": maxDate,
			"minDate": minDate,
			"events": [
				{
					"name": "FieldOnChange",
					"code": "args.owner.field.setDateFieldData(args);"
				}
			],
			"actions": [],
			"dataSource": self.field.dataSource || {
				data: []
			},
			"widget": self.field.widget,
			"parentField": self.field
		};

		field = metaDataFactory.fieldFactory(field);
		field.setIntervalDateData = setIntervalDateData;

		field.setDateFieldData = function(args) {

			this.setIntervalDateData(args);

			if (this.name.indexOf(START_FIELD_SUFFIX) !== -1) {

				var endField = $scope.endField;
				var pseudoEvent = {};
				pseudoEvent[self.field.titleField] = 'interval_pseudo_event';
				pseudoEvent[self.field.dateField] = args.row[endField.parentField.name + START_FIELD_SUFFIX];
				endField.dataSource.data.push(pseudoEvent);

				if (args.row[$scope.startField.name]) {
					endField.openField();
				}
			}
		};

		self.field[field.name] = field;

		return field;
	};

	var intervals = buildIntervals();

	this.buildSelectField = function() {

		var field = {
			"class": "12",
			"name": self.field.name + SELECT_SUFFIX,
			"label": ScreenService.i18n(self.field.label),
			"template": "field/select.html",
			"showSelectAs": "list",
			"readOnly": self.field.isReadOnly(),
			"outData": {
				"_period": self.field.name,
				"_period_label": self.field.name + SELECT_SUFFIX,
				"_period_name": self.field.name + SELECT_INTERVAL_SUFFIX
			},
			"fields": [
				{
					"name": "_period_label",
					"showOnList": true
				}
			],
			"events": [
				{
					"name": "FieldOnChange",
					"code": "args.owner.field.changeIntervalDateFields();"
				}
			],
			"actions": [],
			"dataSource": {
				"data": buildIntervals()
			},
			"widget": self.field.widget,
			"parentField": self.field
		};

		field = metaDataFactory.factoryField(field);
		field.changeIntervalDateFields = changeIntervalDateFields;
		self.field[field.name] = field;

		return field;
	};

	this.field.clearValue = function() {
		clearInternalValues();

		var widget = this.widget;
		if (widget.currentRow[this.name].personalized) {
			widget.currentRow[this.name].start = "";
			widget.currentRow[this.name].end = "";
		}
		widget.currentRow[this.name] = {
			end: "",
			start: ""
		};
		widget.currentRow[self.field.name + SELECT_INTERVAL_SUFFIX] = "";

		templateManager.updateTemplate();
	};

	function clearInternalValues() {
		var widget = self.field.widget;

		widget.currentRow[self.field.name + SELECT_SUFFIX] = "";
		widget.currentRow[self.field.name + START_FIELD_SUFFIX] = "";
		widget.currentRow[self.field.name + END_FIELD_SUFFIX] = "";

		if (self.field[self.field.name + START_FIELD_SUFFIX]) {
			self.field[self.field.name + START_FIELD_SUFFIX].clearValue(self.field[self.field.name + START_FIELD_SUFFIX]);
		}
		if (self.field[self.field.name + END_FIELD_SUFFIX]) {
			self.field[self.field.name + END_FIELD_SUFFIX].clearValue(self.field[self.field.name + END_FIELD_SUFFIX]);
		}

		templateManager.updateTemplate();
	}

	// Functions to set selected data
	var setIntervalDateFields = function() {
		var iField = self.field;
		var widget = iField.widget;

		var row = widget.currentRow[iField.name];
		widget.currentRow[iField.name + START_FIELD_SUFFIX] = row.start;
		widget.currentRow[iField.name + END_FIELD_SUFFIX] = row.end;

		updateIntervalValue(iField, row.start, END_FIELD_SUFFIX, "minDate");
		updateIntervalValue(iField, row.end, START_FIELD_SUFFIX, "maxDate");
	};

	var changeIntervalDateFields = function() {
		var iField = self.field;

		iField.widget.currentRow[iField.name] = Util.clone(iField.widget.currentRow[iField.name]);
		setIntervalDateFields();

		if (Util.isFunction(iField.change)) {
			iField.change();
		}
	};

	this.field.value = function(value) {
		var rowObj;
		if (Util.isObject(value)) {
			rowObj = findInterval(intervals, value);

			if (!rowObj || rowObj.customized || rowObj.personalized) {
				this.widget.currentRow[this.name + SELECT_INTERVAL_SUFFIX] = "";
			}

			setCurrentRow(rowObj, value);
			setIntervalDateFields();
		} else if (Util.isString(value)) {
			var row = getRowObject(value);

			rowObj = findInterval(intervals, row);
			if (rowObj) {
				this.widget.currentRow[this.name + SELECT_INTERVAL_SUFFIX] = value;
			}

			setCurrentRow(rowObj, row);
			setIntervalDateFields();
		} else {
			return this.widget.currentRow[this.name];
		}
	};

	function setCurrentRow(rowObj, row) {
		if (row) {
			self.field.widget.currentRow[self.field.name] = Util.clone(row);
		}
		var currentRow = self.field.widget.currentRow[self.field.name];
		if(currentRow.start || currentRow.end) {
			self.field.widget.currentRow[self.field.name + SELECT_SUFFIX] = rowObj ? rowObj._period_label : "";
			currentRow.personalized = !rowObj;				
		}
	}

	function findInterval(array, compare) {
		return array.filter(function(obj) {
			return obj._period.start === compare.start && obj._period.end === compare.end;
		}).shift();
	}

	var updateIntervalValue = function(iField, value, sufix, limitProperty) {
		if (iField[iField.name + sufix]) {
			iField[iField.name + sufix][limitProperty] = value ? value : iField[limitProperty];
		}
	};

	var setIntervalDateData = function(args) {
		var iField = args.owner.field.parentField;
		var currentRow = iField.widget.currentRow;
		if (!Util.isObject(currentRow[iField.name])) {
			currentRow[iField.name] = {};
		}
		currentRow[iField.name].start = args.row[iField.name + START_FIELD_SUFFIX];
		currentRow[iField.name].end = args.row[iField.name + END_FIELD_SUFFIX];
		currentRow[iField.name + SELECT_SUFFIX] = "";
		currentRow[iField.name + SELECT_INTERVAL_SUFFIX] = "";

		var startFieldValue = iField[iField.name + START_FIELD_SUFFIX].value();
		var endFieldValue = iField[iField.name + END_FIELD_SUFFIX].value();

		updateIntervalValue(iField, startFieldValue, END_FIELD_SUFFIX, "minDate");
		updateIntervalValue(iField, endFieldValue, START_FIELD_SUFFIX, "maxDate");

		if (Util.isFunction(iField.change)) {
			iField.change();
		}

		var endField = $scope.endField;
		var pseudoEvent = endField.dataSource.data.filter(function(item) {
			return item[self.field.titleField] == 'interval_pseudo_event';
		});

		if (pseudoEvent.length) {
			endField.dataSource.data.splice(endField.dataSource.data.indexOf(pseudoEvent[0]), 1);
		}
	};

	this.isPersonalizedPeriod = function() {
		return self.field.widget.currentRow[self.field.name].personalized;
	};

	this.isRowSet = function() {
		return $scope.field.widget.currentRow[$scope.startField.name] || $scope.field.widget.currentRow[$scope.endField.name];
	};

	this.getPeriodLabel = function() {
		var label = self.field.widget.currentRow[self.field.name + SELECT_SUFFIX] || "";
		if (label) {
			label = "(" + label + ")";
		}
		return label;
	};

	self.field.value(self.field.value() || self.field.defaultValue);

	// Validations

	$scope.isRequired = function(field) {
		return field.validations && (field.validations.requiredInterval || field.validations.requiredIntervalStart || field.validations.requiredIntervalEnd);
	};

	function required(value, validationAttrs) {
		return {
			"valid": requiredStart(value, validationAttrs).valid && requiredEnd(value, validationAttrs).valid,
			"message": ScreenService.i18n(validationAttrs.message) || ScreenService.i18n("Required field")
		};
	}

	function requiredStart(value, validationAttrs) {
		return {
			"valid": value && Util.isObject(value) && !Util.isEmptyOrBlank(value.start),
			"message": ScreenService.i18n(validationAttrs.message) || ScreenService.i18n("Required field")
		};
	}

	function requiredEnd(value, validationAttrs) {
		return {
			"valid": value && Util.isObject(value) && !Util.isEmptyOrBlank(value.end),
			"message": ScreenService.i18n(validationAttrs.message) || ScreenService.i18n("Required field")
		};
	}

	var registeredValidations = validateEngine.getMappedValidations();

	var validationsToRegister = {
		"requiredInterval": required,
		"requiredIntervalStart": requiredStart,
		"requiredIntervalEnd": requiredEnd
	};

	for (var validationName in validationsToRegister) {
		if (!registeredValidations.hasOwnProperty(validationName)) {
			validateEngine.registerValidation(validationName, validationsToRegister[validationName]);
		}
	}

}