package com.javaseleniumtemplate.pages;

import com.javaseleniumtemplate.bases.PageBase;
import org.openqa.selenium.By;
import org.openqa.selenium.Keys;
import org.openqa.selenium.interactions.Actions;
import org.testng.Assert;

public class PratoXPorcionamentoPage extends PageBase {

    By botaoMenu = By.xpath("//div[@class='bars']");
    By campoPesquisar = By.xpath("//section[@class='zh-container-search-menu']//input[@type='text']");
    By opcaoTelaPratoXProcionamento = By.xpath("//span[text() = 'Prato x Porcionamento']");

    By botaoAdicionar = By.xpath("//div[@class=\"zh-footer-center\"]//li[@class=\"zh-ripple-effect\"]");
    By botaoSalvar = By.xpath("//div[@class=\"zh-footer-right\"]");
    By botaoOk = By.xpath("//section[@class=\"popup-container\"]//div[@class=\"zh-footer-right\"]");
    By botaoOkAlert = By.xpath("//section[@class=\"zh-container-alert\"]//button[@type=\"submit\"]");
    By botaoSim = By.xpath("//section[@class=\"zh-container-alert\"]//footer[@class=\"zh-footer-alert\"]/button[1]");
    By botaoVoltar = By.xpath("//div[@class=\"zh-footer-left\"]");
    By botaoCancelar = By.xpath("//div[@class=\"zh-footer-left\"]");

    By campoPrato = By.id("NMPRATO");
    By pratoFeijoadaSimples = By.xpath("//div[@id=\"grid-9999\"]//div[@data-zh-field-name=\"NMPRATO\"]//span[text() = 'FEIJOADA SIMPLES']");
    By pratoFeijoadaMagra = By.xpath("//div[@data-zh-field-name=\"NMPRATO\"]//span[text() = 'FEIJOADA MAGRA']");
    By campoPorcionamento = By.id("NMMEDICASE");
    By porcionamentoColherSopa = By.xpath("//div[@data-zh-id=\"12211565841717605791664\"]//span[text() = '00003 | COLHER DE SOPA']");
    By porcionamentoColherDeCha = By.xpath("//div[@data-zh-id=\"12211565841717605791664\"]//span[text() = '00004 | COLHER DE CHÁ']");
    By campoQuantidade = By.id("VRPESOMED");

    By mensagemAlerta = By.xpath("//section[@class=\"zh-container-alert\"]//div[@class=\"zh-alert-scroll\"]/p");
    By mensagemSucesso = By.xpath("//*[@class=\"zh-notification-messages\"]//span[@class=\"notification-message-text\"]");

    By codigoPrimeiroPrato = By.xpath("//div[@id=\"grid-122115658432633229659\"]//div[@class=\"body-content\"]/div[1]/div[1]/span");
    By nomePrimeiroPrato = By.xpath("//div[@id=\"grid-122115658432633229659\"]//div[@class=\"body-content\"]/div[1]/div[2]/span");
    By unidadePrimeiroPrato = By.xpath("//div[@id=\"grid-122115658432633229659\"]//div[@class=\"body-content\"]/div[1]/div[3]/span");

    By botaoExcluirPrimeiroPorcionamento = By.xpath("//div[@id=\"grid-12211565841548132603661\"]//div[@class=\"body-content\"]/div[1]/div[1]");
    By nomePrimeiroPorcionamento = By.xpath("//div[@id=\"grid-12211565841548132603661\"]//div[@class=\"body-content\"]/div[1]/div[2]/span");
    By quantidadePrimeiroPorcionamento = By.xpath("//div[@id=\"grid-12211565841548132603661\"]//div[@class=\"body-content\"]/div[1]/div[3]/span");

    public void acessarTela() {
        tempoParaAguardarTelaInicial();
        waitForElement(botaoMenu);
        click(botaoMenu);
        sendKeys(campoPesquisar, "Prato x Porcionamento");
        click(opcaoTelaPratoXProcionamento);
    }

    public void adicionarRegistro() {
        click(botaoAdicionar);
        click(campoPrato);
        click(pratoFeijoadaSimples);
        click(pratoFeijoadaMagra);
        click(botaoOk);
        clicarCampoSelecionarValor(campoPorcionamento, porcionamentoColherSopa);
        sendKeys(campoQuantidade, "5,2");
        click(botaoSalvar);

        String mensagem = getText(mensagemSucesso);
        String mensagemEsperada = "Registro adicionado com sucesso!";
        Assert.assertEquals(mensagem, mensagemEsperada, "Verificação da mensagem de sucesso exibida na tela, após o registro ser adicionado");

        //valores encontrados
        String codigo = getText(codigoPrimeiroPrato);
        String nome = getText(nomePrimeiroPrato);
        String unidade = getText(unidadePrimeiroPrato);

        //valores esperados
        String expCodigo = "00.00.00.001";
        String expNome = "FEIJOADA SIMPLES";
        String expUnidade = "KG";

        Assert.assertEquals(codigo, expCodigo, "Verificação do código do primeiro prato adicionado");
        Assert.assertEquals(nome, expNome, "Verificação do nome do primeiro prato adicionado");
        Assert.assertEquals(unidade, expUnidade, "Verificação da unidade do primeiro prato adicionado");
    }

    public void verificarPorcionamento() {
        click(nomePrimeiroPrato);
        //valores encontrados no primeiro procionamento
        String nome = getText(nomePrimeiroPorcionamento);
        String quantidade = getText(quantidadePrimeiroPorcionamento);

        //valores esperados
        String expNome = "COLHER DE SOPA";
        String expQuantidade = "5,20";
        Assert.assertEquals(nome, expNome, "Verificação do nome do porcionamento adicionado no primeiro registro");
        Assert.assertEquals(quantidade, expQuantidade, "Verificação da quantidade do porcionamento adicionado no primeiro registro");
    }

    public void editarQuantidadePorcionamento() {
        Actions actions = new Actions(driver);
        actions.moveToElement(driver.findElement(quantidadePrimeiroPorcionamento)).click().build().perform();
        tempo();
        actions.sendKeys(Keys.BACK_SPACE).build().perform();
        tempo();
        actions.sendKeys("6").build().perform();
        tempo();
        actions.sendKeys(Keys.ENTER).build().perform();

        click(botaoSalvar);
        String mensagem = getText(mensagemSucesso);
        String mensagemEsperada = "Alteração realizada com sucesso!";
        Assert.assertEquals(mensagem, mensagemEsperada, "Verificação da mensagem sucesso exibida após a edição da quantidade");

        String quantidadeEdit = getText(quantidadePrimeiroPorcionamento);
        Assert.assertEquals(quantidadeEdit, "6,00", "Verificação da quantidade após a edição");
    }

    public void addSegundoPorcAoMesmoPrato() {
        click(botaoAdicionar);
        clicarCampoSelecionarValor(campoPorcionamento, porcionamentoColherDeCha);
        sendKeys(campoQuantidade, "3");
        click(botaoSalvar);

        String mensagem = getText(mensagemSucesso);
        String mensagemEsperada = "Registro adicionado com sucesso!";
        Assert.assertEquals(mensagem, mensagemEsperada, "Verificação da mensagem de sucesso exibida na tela, após o registro ser adicionado");

        //valores encontrados no primeiro procionamento
        String nome = getText(nomePrimeiroPorcionamento);
        String quantidade = getText(quantidadePrimeiroPorcionamento);

        //valores esperados
        String expNome = "COLHER DE CHÁ";
        String expQuantidade = "3,00";
        Assert.assertEquals(nome, expNome, "Verificação do nome do segundo porcionamento adicionado ao prato Feijoada Simples");
        Assert.assertEquals(quantidade, expQuantidade, "Verificação da quantidade do segundo porcionamento adicionado ao prato Feijoada Simples");
    }

    public void excluirPorcionamentos(int quantPorcionamento) {
        for (int quant = 1; quant <= quantPorcionamento; quant ++) {
            click(botaoExcluirPrimeiroPorcionamento);
            String mensagem = getText(mensagemAlerta);
            Assert.assertEquals(mensagem, "Deletar o registro?", "Verificação da mensagem de alerta exibida após clicar no excluir do porcionamento");
            click(botaoSim);

            tempo();
            String mensagemExcluidoSucesso = getText(mensagemSucesso);
            Assert.assertEquals(mensagemExcluidoSucesso, "Excluído com sucesso.", "Verificação da mensagem de excluído om sucesso, após a exclusão da medida");
        }
    }

    public void verificarSegunPratoFeijoadaMagra() {
        //valores encontrados
        String codigo = getText(codigoPrimeiroPrato);
        String nome = getText(nomePrimeiroPrato);
        String unidade = getText(unidadePrimeiroPrato);

        //valores esperados
        String expCodigo = "00.00.00.002";
        String expNome = "FEIJOADA MAGRA";
        String expUnidade = "KG";

        Assert.assertEquals(codigo, expCodigo, "Verificação do código do primeiro prato adicionado");
        Assert.assertEquals(nome, expNome, "Verificação do nome do primeiro prato adicionado");
        Assert.assertEquals(unidade, expUnidade, "Verificação da unidade do primeiro prato adicionado");
    }

    public void addPratoFeijoadaSimples() {
        click(botaoAdicionar);
        click(campoPrato);
        tempo();
        click(pratoFeijoadaSimples);
        click(botaoOk);
        clicarCampoSelecionarValor(campoPorcionamento, porcionamentoColherSopa);
        sendKeys(campoQuantidade, "2,8");
        click(botaoSalvar);

        String mensagem = getText(mensagemAlerta);
        String mensagemEsperada = "O porcionamento dos seguintes pratos será sobreposto (FEIJOADA SIMPLES). Deseja continuar?";
        Assert.assertEquals(mensagem, mensagemEsperada, "Verificação da mensagem exbida quando o usuário tenta adicionar um registro com um prato "
            + "e porcionamento que já existem. Dessa forma o registro será sobreposto");
        click(botaoSim);

        tempo();
        click(nomePrimeiroPrato);
        String quantidade = getText(quantidadePrimeiroPorcionamento);
        String expQuantidade = "2,80";
        Assert.assertEquals(quantidade, expQuantidade, "Verificação do valor da quantidade, após a mesma ser sobreposta");
        click(botaoVoltar);
    }

    public void addPratoFeijoadaSimplesPorcDiferente() {
        tempo();
        click(botaoAdicionar);
        click(campoPrato);
        tempo();
        click(pratoFeijoadaSimples);
        click(botaoOk);
        clicarCampoSelecionarValor(campoPorcionamento, porcionamentoColherDeCha);
        sendKeys(campoQuantidade, "4,3");
        click(botaoSalvar);

        tempo();
        click(nomePrimeiroPrato);
        String nome = getText(nomePrimeiroPorcionamento);
        String quantidade = getText(quantidadePrimeiroPorcionamento);

        String expNome = "COLHER DE CHÁ";
        String expQuantidade = "4,30";
        Assert.assertEquals(quantidade, expQuantidade, "Verificação do valor da quantidade, após adicionar o mesmo prato, porém com um porcionamento diferente");
        Assert.assertEquals(nome, expNome, "Verificação do valor do nome, após adicionar o mesmo prato, porém com um porcionamento diferente");
    }

    public void tentarAddMesmoPorcionamentoAoMesmoPrato() {
        click(botaoAdicionar);
        clicarCampoSelecionarValor(campoPorcionamento, porcionamentoColherDeCha);
        sendKeys(campoQuantidade, "8,6");
        click(botaoSalvar);

        String mensagem = getText(mensagemAlerta);
        String mensagemEsperada = "Impossível adicionar. Registro já existe.";
        Assert.assertEquals(mensagem, mensagemEsperada, "Verificação da mensagem que é exibida na tela após tentar adicionar ao prato um porcionamento que o mesmo já possuí");

        click(botaoOkAlert);
        click(botaoCancelar);
    }

}
